@@ -19,7 +19,7 @@ from base64 import b64encode
 from urllib.parse import quote
 
 import aiohttp
-import backoff
+import backoff  # type: ignore
 
 from . import __version__
 from .utils import filter_items
@@ -898,6 +898,26 @@ class HTTPClient:
 
         return self.request(route, params=payload)
 
+    def playback_queue(self, *, uri: str, device_id: Optional[str] = None) -> Awaitable:
+        """Add an item to the end of the user’s current playback queue.
+
+        Parameters
+        ----------
+        uri : :class:`str`
+            The uri of the item to add to the queue. Must be a track or an
+            episode uri.
+        device_id : :class:`str`
+            The id of the device this command is targeting. If not supplied,
+            the user’s currently active device is the target.
+        """
+        route = self.route("POST", "/me/player/queue")
+        params = {"uri": uri}
+
+        if device_id is not None:
+            params["device_id"] = device_id
+
+        return self.request(route, params=params)
+
     def recently_played(
         self,
         *,
@@ -1443,7 +1463,7 @@ class HTTPClient:
     def remove_playlist_tracks(
         self,
         playlist_id: str,
-        tracks: Sequence[Union[str, Dict[str, Union[str, int]]]],
+        tracks: Sequence[Union[str, Dict[str, Any]]],
         *,
         snapshot_id: str = None,
     ) -> Awaitable:
