@@ -39,6 +39,24 @@ def ensure_http(func):
     return func
 
 
+class WrappedUser:
+    def __init__(self, coro):
+        self.coro = coro
+        self.user = None
+
+    async def __await__(self):
+        return await self.coro
+
+    async def __aenter__(self):
+        if self.user is None:
+            self.user = user = await self.coro
+
+        return await user.__aenter__()
+
+    async def __aexit__(self, exc_type, exc_value, traceback):
+        await self.user.__aexit__(exc_type, exc_value, traceback)
+
+
 class User(URIBase, AsyncIterable):  # pylint: disable=too-many-instance-attributes
     """A Spotify User.
 
@@ -121,6 +139,12 @@ class User(URIBase, AsyncIterable):  # pylint: disable=too-many-instance-attribu
             return _raise
         return value
 
+    async def __aenter__(self) -> "User":
+        return self
+
+    async def __aexit__(self, _, __, ___):
+        await self.http.close()
+
     # Internals
 
     async def _get_top(self, klass: Type[T], kwargs: dict) -> List[T]:
@@ -175,12 +199,12 @@ class User(URIBase, AsyncIterable):  # pylint: disable=too-many-instance-attribu
         return await cls.from_token(client, token, refresh_token)
 
     @classmethod
-    async def from_token(
+    def from_token(
         cls,
         client: "spotify.Client",
         token: Optional[str],
         refresh_token: Optional[str] = None,
-    ):
+    ) -> WrappedUser:
         """Create a :class:`User` object from an access token.
 
         Parameters
@@ -194,9 +218,13 @@ class User(URIBase, AsyncIterable):  # pylint: disable=too-many-instance-attribu
         """
         client_id = client.http.client_id
         client_secret = client.http.client_secret
-        http = HTTPUserClient(client_id, client_secret, token, refresh_token)
-        data = await http.current_user()
-        return cls(client, data=data, http=http)
+
+        async def constructor() -> "User":
+            http = HTTPUserClient(client_id, client_secret, token, refresh_token)
+            data = await http.current_user()
+            return cls(client, data=data, http=http)
+
+        return WrappedUser(coro=constructor())
 
     @classmethod
     async def from_refresh_token(cls, client: "spotify.Client", refresh_token: str):
@@ -263,7 +291,13 @@ class User(URIBase, AsyncIterable):  # pylint: disable=too-many-instance-attribu
         return [Device(item) for item in data["devices"]]
 
     @ensure_http
-    async def recently_played(self) -> List[Dict[str, Union[Track, Context, str]]]:
+    async def recently_played(
+        self,
+        *,
+        limit: int = 20,
+        before: Optional[str] = None,
+        after: Optional[str] = None,
+    ) -> List[Dict[str, Union[Track, Context, str]]]:
         """Get tracks from the current users recently played tracks.
 
         Returns
@@ -272,7 +306,7 @@ class User(URIBase, AsyncIterable):  # pylint: disable=too-many-instance-attribu
             A list of playlist history object.
             Each object is a dict with a timestamp, track and context field.
         """
-        data = await self.http.recently_played()  # type: ignore
+        data = await self.http.recently_played(limit=limit, before=before, after=after)  # type: ignore
         client = self.__client
 
         # List[T] where T: {'track': Track, 'content': Context: 'timestamp': ISO8601}
